CoapCode

Struct CoapCode 

pub struct CoapCode {
    pub class: u8,
    pub detail: u8,
}
CoAP response/request code (RFC 7252 3, 5.9).

Encoded as a single byte: upper 3 bits = class, lower 5 bits = detail. Conventionally written as class.detail (e.g., 2.05 = Content).

Fields

class: u8

Code class (0 = request, 2 = success, 4 = client error, 5 = server error).

detail: u8

Code detail within the class.

Implementations

Source

impl CoapCode

pub const CREATED: Self

2.01 Created — enrollment succeeded.

pub const CONTENT: Self

2.05 Content — response with payload.

pub const NOT_FOUND: Self

4.04 Not Found — unknown URI path.

pub const METHOD_NOT_ALLOWED: Self

4.05 Method Not Allowed — wrong method for resource.

pub const UNSUPPORTED_CONTENT_FORMAT: Self

4.15 Unsupported Content-Format.

pub const INTERNAL_SERVER_ERROR: Self

5.00 Internal Server Error.

pub fn to_byte(&self) -> u8

Encodes the code as a single byte: class in bits 7-5, detail in bits 4-0.

pub fn from_byte(byte: u8) -> Self

Decodes a code from a single byte.

pub fn is_request(&self) -> bool

Returns whether this code represents a request (class 0).

pub fn is_success(&self) -> bool

Returns whether this code represents a success response (class 2).

pub fn is_client_error(&self) -> bool

Returns whether this code represents a client error (class 4).

pub fn is_server_error(&self) -> bool

Returns whether this code represents a server error (class 5).