pub struct CoapOption {
pub number: u16,
pub value: Vec<u8>,
}Expand description
A single CoAP option (RFC 7252 3.1).
Options are TLV-encoded in messages, sorted by option number. Repeated option numbers create multiple values for that option.
Fields
number: u16Option number (determines semantics).
value: Vec<u8>Option value (interpretation depends on the option number).
Implementations
Sourceimpl CoapOption
impl CoapOption
Sourcepub fn new(number: u16, value: Vec<u8>) -> Self
pub fn new(number: u16, value: Vec<u8>) -> Self
Creates a new option with the given number and value.
Sourcepub fn value_as_uint(&self) -> u32
pub fn value_as_uint(&self) -> u32
Interprets the option value as a variable-length unsigned integer.
RFC 7252 3.2: Options with format “uint” use 0-4 bytes in network byte order.
Sourcepub fn from_uint(number: u16, value: u32) -> Self
pub fn from_uint(number: u16, value: u32) -> Self
Creates an option with a uint value encoded in the minimum number of bytes.
Sourcepub fn value_as_str(&self) -> CoapResult<&str>
pub fn value_as_str(&self) -> CoapResult<&str>
Interprets the option value as a UTF-8 string.